#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 setlocale
version:              1.0.0.10
visibility:           public
id:                   setlocale-1.0.0.10-HH45IWXdMTEGcVsXOuIxfh
key:                  setlocale-1.0.0.10-HH45IWXdMTEGcVsXOuIxfh
license:              BSD-3-Clause
copyright:            2014-2021, Sven Bartscher
maintainer:           sven.bartscher@weltraumschlangen.de
author:               Sven Bartscher
homepage:             https://gitlab.com/Kritzefitz/haskell-setlocale/
synopsis:             Haskell bindings to setlocale
category:             System
abi:                  360658f65a25e09a3535a9f89768c19c
exposed:              True
exposed-modules:      System.Locale.SetLocale
import-dirs:          /usr/lib/ghc-9.6.6/site-local/setlocale-1.0.0.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/setlocale-1.0.0.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/setlocale-1.0.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-setlocale
hs-libraries:         HSsetlocale-1.0.0.10-HH45IWXdMTEGcVsXOuIxfh
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-setlocale/html/setlocale.haddock
haddock-html:         /usr/share/doc/haskell-setlocale/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

